@@ -8,6 +8,15 @@ from typing import List, Literal, Optional
 def get_folders(
     folders: List[str] | str, area: Literal["MP", "G2", "G3", "O2"]
 ) -> List[str]:
+    """Gets the folders containing the specified areas from all folders.
+
+    Args:
+        folders (List[str] | str): List or comma separated string containing all folders.
+        area (Literal['MP', 'G2', 'G3', 'O2']): Area the foldername must contain.
+
+    Returns:
+        List[str]: List of folders
+    """
     folders_list = []
     result = []
     if isinstance(folders, str):
@@ -20,7 +29,16 @@ def get_folders(
     return result
 
 
-def get_pass_file_by_date(d: date, folder: str):
+def _get_pass_file_by_date(d: date, folder: str) -> List[str]:
+    """Get pass files by date.
+
+    Args:
+        d (date): date contained in the file name.
+        folder (str): root folder that contains the file.
+
+    Returns:
+        List[str]: List of files.
+    """
     files = []
 
     files = files + glob.glob(
@@ -37,7 +55,17 @@ def get_pass_files(
     start_date: Optional[date] = None,
     end_date: Optional[date] = None,
 ) -> List[str]:
+    """Get the pass files. The get__files methods are separated, because the folder structures are very different.
 
+    Args:
+        folders (List[str]): List of relevant folders. Should be obtained by get_folders.
+        root_dir (str): Root dir of the folders.
+        start_date (Optional[date], optional): Earliest date the files should match. Defaults to None.
+        end_date (Optional[date], optional): Latest date the files should match. Defaults to None.
+
+    Returns:
+        List[str]: List of files matching the parameters.
+    """
     result = []
     all_files = []
     for folder in folders:
@@ -55,11 +83,11 @@ def get_pass_files(
             if not start_date or not end_date:
                 datetime = start_date or end_date
                 date = datetime.date()
-                files = get_pass_file_by_date(date, folder=folder)
+                files = _get_pass_file_by_date(date, folder=folder)
             else:
                 date = start_date
                 while date < end_date:
-                    files = files + get_pass_file_by_date(date, folder=folder)
+                    files = files + _get_pass_file_by_date(date, folder=folder)
                     date = date + timedelta(days=1)
             if files:
                 for file in files:
@@ -79,6 +107,23 @@ def get_files(
     end_datetime: Optional[datetime] = None,
     area: Optional[Literal["G2", "G3", "O2"]] = None,
 ) -> List[str]:
+    """Get the tcs trace and slowControl files. The get__files methods are separated, because the folder structures are very different.
+
+    Args:
+        folders (List[str] | str): Relevant folders to be searched.
+        system (Literal['tds', 'tvs']): System the file should log.
+        tcs_type (Literal['SlowControl', 'TcsTrace']): Type of file.
+        root_dir (Optional[str], optional): Root dir of folders. Defaults to None.
+         start_date (Optional[date], optional): Earliest datetime the files should match. Defaults to None.
+        end_date (Optional[date], optional): Latest datetime the files should match. Defaults to None.
+        area (Optional[Literal['G2', 'G3', 'O2']], optional): Area the files should be from. Defaults to None.
+
+    Raises:
+        Exception: No files found
+
+    Returns:
+        List[str]: List of files.
+    """
     files = []
     files_found = []
     _folders = []
